<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX" sourcelanguage="en">
<context>
    <name>About</name>
    <message>
        <location filename="../../src/about.ui" line="17"/>
        <source>About KDiskMark</source>
        <translation>Acerca de KDiskMark</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="62"/>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="88"/>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="114"/>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="146"/>
        <source>E-mail:</source>
        <translation>Correo Electrónico:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="178"/>
        <source>Flexible I/O Tester:</source>
        <translation>Flexible I/O Tester:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="204"/>
        <source>Application Icon:</source>
        <translation>Icono de Aplicación:</translation>
    </message>
</context>
<context>
    <name>Benchmark</name>
    <message>
        <location filename="../../src/benchmark.cpp" line="232"/>
        <source>Preparing...</source>
        <translation>Preparando...</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="254"/>
        <source>Sequential Read %1/%2</source>
        <translation>Lectura Secuencial %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="264"/>
        <source>Sequential Write %1/%2</source>
        <translation>Escritura Secuencial %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="274"/>
        <source>Sequential Mix %1/%2</source>
        <translation>Mezcla Secuencial %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="405"/>
        <source>Could not obtain administrator privileges.</source>
        <translation>No se han podido obtener privilegios de administrador.</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="258"/>
        <source>Random Read %1/%2</source>
        <translation>Lectura Aleatoria %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="268"/>
        <source>Random Write %1/%2</source>
        <translation>Escritura Aleatoria %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="278"/>
        <source>Random Mix %1/%2</source>
        <translation>Mezcla Aleatoria %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="285"/>
        <source>Interval Time %1/%2 sec</source>
        <translation>Intervalo de Tiempo %1/%2</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.ui" line="30"/>
        <location filename="../../src/mainwindow.cpp" line="917"/>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="351"/>
        <location filename="../../src/mainwindow.ui" line="933"/>
        <location filename="../../src/mainwindow.cpp" line="547"/>
        <source>Read</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="520"/>
        <location filename="../../src/mainwindow.ui" line="952"/>
        <location filename="../../src/mainwindow.cpp" line="550"/>
        <source>Write</source>
        <translation>Escritura</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="686"/>
        <location filename="../../src/mainwindow.cpp" line="553"/>
        <source>Mix</source>
        <translation>Mezcla</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="220"/>
        <location filename="../../src/mainwindow.cpp" line="436"/>
        <location filename="../../src/mainwindow.cpp" line="440"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="225"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="230"/>
        <location filename="../../src/mainwindow.cpp" line="442"/>
        <location filename="../../src/mainwindow.cpp" line="443"/>
        <source>IOPS</source>
        <translation>IOPS</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="235"/>
        <location filename="../../src/mainwindow.cpp" line="445"/>
        <location filename="../../src/mainwindow.cpp" line="446"/>
        <source>μs</source>
        <translation>μs</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1017"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1025"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1029"/>
        <source>Test Data</source>
        <translation>Datos de prueba</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1047"/>
        <source>Profile</source>
        <translation>Perfil</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1063"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1067"/>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1075"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1091"/>
        <source>About KDiskMark</source>
        <translation>Acerca de KDiskMark</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1096"/>
        <source>Queues &amp;&amp; Threads</source>
        <translation>Colas &amp;&amp; Hilos</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1101"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1106"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1111"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1122"/>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1130"/>
        <source>Peak Performance</source>
        <translation>Máximo Rendimiento</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1138"/>
        <source>Real World Performance</source>
        <translation>Rendimiento en el Mundo Real</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1146"/>
        <source>Default [+Mix]</source>
        <translation>Predeterminado [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1154"/>
        <source>Peak Performance [+Mix]</source>
        <translation>Máximo Rendimiento [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1162"/>
        <source>Real World Performance [+Mix]</source>
        <translation>Rendimiento en el Mundo Real [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1173"/>
        <source>Flush Pagecache</source>
        <translation>Limpiar Pagecache</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1181"/>
        <source>Demo</source>
        <translation>Demo</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1192"/>
        <source>Read and Write [+Mix]</source>
        <translation>Lectura y escritura [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1200"/>
        <source>Read [+Mix]</source>
        <translation>Lectura [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1208"/>
        <source>Write [+Mix]</source>
        <translation>Escritura [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1219"/>
        <source>Random</source>
        <translation>Aleatorio</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1227"/>
        <source>Fill with zeros</source>
        <translation>Rellenar con ceros</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1238"/>
        <source>Standard Preset</source>
        <translation>Preselección estándar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1246"/>
        <source>NVMe SSD</source>
        <translation>NVMe SSD</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1257"/>
        <source>Use Fusion</source>
        <translation>Utilizar Fusión</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1265"/>
        <source>Stylesheet Light</source>
        <translation>Hoja de estilo Light</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1273"/>
        <source>Stylesheet Dark</source>
        <translation>Hoja de estilo Dark</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1281"/>
        <source>Do not apply</source>
        <translation>No utilice</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1292"/>
        <source>Use O_DIRECT</source>
        <translation>Utilizar O_DIRECT</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1303"/>
        <source>CoW detection</source>
        <translation>Detección de CoW</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="54"/>
        <source>The device is encrypted. Performance may drop.</source>
        <translation>El dispositivo está encriptado. El rendimiento podría ser menor.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="352"/>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="356"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="263"/>
        <location filename="../../src/mainwindow.cpp" line="322"/>
        <source>Add a directory</source>
        <translation>Agregar un directorio</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="892"/>
        <location filename="../../src/mainwindow.cpp" line="893"/>
        <location filename="../../src/mainwindow.cpp" line="894"/>
        <location filename="../../src/mainwindow.cpp" line="895"/>
        <location filename="../../src/mainwindow.cpp" line="896"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="944"/>
        <source>Stopping...</source>
        <translation>Deteniendo...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Directory is not specified.</source>
        <translation>Directorio no especificado.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1059"/>
        <source>Copy-on-Write (CoW) is enabled on the selected directory.</source>
        <translation>El copiado al escribir (CoW) está habilitado en el directorio seleccionado.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1060"/>
        <source>This may affect performance results. Would you like to create a new subdirectory with CoW disabled?</source>
        <translation>Esto puede afectar los resultados de rendimiento. ¿Desea crear un nuevo subdirectorio con CoW deshabilitado?</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="vanished">Confirmación</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="964"/>
        <source>Benchmark Failed</source>
        <translation>Benchmark Falló</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/global.cpp" line="25"/>
        <source>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Queues=%4&lt;br/&gt;Threads=%5%6&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Colas=%4&lt;br/&gt;Hilos=%5%6&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Sequential</source>
        <translation>Secuencial</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Random</source>
        <translation>Aleatorio</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="34"/>
        <source>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="200"/>
        <source>No FIO was found. Please install FIO before using KDiskMark.</source>
        <translation>No se ha encontrado la FIO. Por favor, instale la FIO antes de usar KDiskMark.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../src/settings.ui" line="14"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="149"/>
        <source>Block Size</source>
        <translation>Tamaño de Bloque</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="165"/>
        <source>Queues</source>
        <translation>Colas</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="181"/>
        <source>Threads</source>
        <translation>Hilos</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="280"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="335"/>
        <source>Profile: Peak Performance</source>
        <translation>Perfil: Máximo Rendimiento</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="446"/>
        <source>Profile: Demo</source>
        <translation>Perfil: Demo</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="508"/>
        <source>Measuring time</source>
        <translation>Tiempo de medición</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="530"/>
        <source>Interval time</source>
        <translation>Intervalo</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="257"/>
        <source>Profile: Default</source>
        <translation>Perfil: Predeterminado</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="18"/>
        <location filename="../../src/settings.cpp" line="23"/>
        <source>sec</source>
        <translation>seg</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="19"/>
        <location filename="../../src/settings.cpp" line="24"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="71"/>
        <location filename="../../src/settings.cpp" line="72"/>
        <location filename="../../src/settings.cpp" line="73"/>
        <location filename="../../src/settings.cpp" line="74"/>
        <location filename="../../src/settings.cpp" line="76"/>
        <location filename="../../src/settings.cpp" line="77"/>
        <location filename="../../src/settings.cpp" line="79"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="59"/>
        <location filename="../../src/settings.cpp" line="60"/>
        <location filename="../../src/settings.cpp" line="61"/>
        <location filename="../../src/settings.cpp" line="62"/>
        <location filename="../../src/settings.cpp" line="64"/>
        <location filename="../../src/settings.cpp" line="65"/>
        <location filename="../../src/settings.cpp" line="67"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
</context>
</TS>
